@@ -1,6 +1,7 @@
 package Mojolicious::Plugin::AttributeMaker::Extension::Routing;
 use parent 'Mojolicious::Plugin::AttributeMaker::Extension';
-
+use strict;
+use warnings;
 our $VERSION = 0.01;
 
 =head1 NAME
@@ -15,9 +16,6 @@ Version 0.01
 
 =head1 ATTRIBUTES
 
-Example app namespace : MyApp
-Example app contrioller namespace : MyApp::Controller
-
 =head2 Local
 
 Example:
@@ -27,7 +25,8 @@ Example:
     
     http://*:port/simple/homepage
 
-A local atrribute ignore arguments
+The Local attribute does not use (ignores) arguments
+
 =cut
 
 =head2 Path
@@ -39,7 +38,9 @@ Example:
     
     http://*:port/simple/user_home
 
-A path atrribute has one mandatory argument
+The Path attribute requires one argument.
+If given parameter has a slash in it (i.e. "Path('/user_home')") then his behaviour will match the Global attribute behaviour and will refer to URL root folder ('http://mysite.host/user_home')
+If given parameter has NO slash in it (i.e. "Path('user_home')") then generated link will use controller name and the parameter given in the attribute ('http://mysite.host/CONTROLLER_NAME/user_home')
 
 =cut
 
@@ -56,6 +57,7 @@ So the above is the same as:
     
     sub myaction :Path("/homepage") { ... }
    
+   
 But if you write this:
     
     sub homepage :Global('/homepage_custom_url') { ... }
@@ -78,9 +80,13 @@ __PACKAGE__->make_attribute(
     Global => sub {
         my ( $package, $method, $plugin, $mojo_app, $attrname, $attrdata ) = @_;
         my $controller = _get_controller_name($package);
-        my $url        = $method;
+        my $config     = $plugin->config();
+        my $url        = $config->{namespace} . "";
         if ($attrdata) {
-            $url = $attrdata->[0];
+            $url .= $attrdata->[0];
+        }
+        else {
+            $url .= $method;
         }
         _add_route( $plugin, $controller, $method, $url, $attrname );
     }
@@ -88,15 +94,16 @@ __PACKAGE__->make_attribute(
 __PACKAGE__->make_attribute(
     Path => sub {
         my ( $package, $method, $plugin, $mojo_app, $attrname, $attrdata ) = @_;
-        my $controller = _get_controller_name($package);
-        my $url        = $method;
         my $config     = $plugin->config();
+        my $controller = _get_controller_name($package);
+        my $url        = $config->{namespace} . "";
+
         if ($attrdata) {
             if ( 0 == index( $attrdata->[0], '/' ) ) {
-                $url = $config->{namespace} . "" . lc $attrdata->[0];
+                $url .= $attrdata->[0];
             }
             else {
-                $url = $config->{namespace} . $controller . "/" . $attrdata->[0];
+                $url .= $controller . "/" . $attrdata->[0];
             }
         }
         else {
@@ -111,11 +118,11 @@ sub _get_controller_name($) {
     return ( split( '::', $_[0] ) )[-1];
 }
 
-sub _add_route() {
+sub _add_route {
     my $plugin = shift;
 
     #[ 'Controller', 'Action', 'Url', 'Type' ]
-    $_[2] = "/" . $_[2]; # append slash first...may be hack,may be no 
+    $_[2] = "/" . $_[2];    # append slash first...may be hack,may be no
     $_[2] =~ s/\/+/\//g;
     $plugin->config()->{urls}->{ lc $_[2] } = { attr => $_[3], url => lc $_[2] };
     $plugin->config->{app}->routes->route( lc $_[2] )->to( controller => $_[0], action => $_[1] );
